@@ -1145,6 +1145,8 @@ class EntryManipulatingResource(ReadWriteResource):
             if force_clear or new_value != old_value:
                 del(self._unmarshalled_field_cache[name])
 
+        self._applyChangesPostHook()
+
         new_url = absoluteURL(self.entry.context, self.request)
         if new_url == original_url:
             # The resource did not move. Serve a new representation of
@@ -1164,6 +1166,13 @@ class EntryManipulatingResource(ReadWriteResource):
             # SHOULD be a note linking to the new object.
             return ''
 
+    def _applyChangesPostHook(self):
+        """A hook method called near the end of applyChanges.
+
+        This method is called after the changes have been applied, but
+        before the new representation is created.
+        """
+        pass
 
 class EntryFieldResource(FieldUnmarshallerMixin, EntryManipulatingResource):
     """An individual field of an entry."""
@@ -1262,6 +1271,17 @@ class EntryResource(CustomOperationResourceMixin,
         super(EntryResource, self).__init__(context, request)
         self.entry = getMultiAdapter((context, request), IEntry)
 
+    def handleCustomPOST(self, operation_name):
+        """See `CustomOperationResourceMixin`."""
+        value = super(EntryResource, self).handleCustomPOST(operation_name)
+        # We don't know what the custom operation might have done.
+        # Remove this object from the representation cache, just to be
+        # safe.
+        cache = self._representation_cache
+        if cache is not None:
+            cache.delete(self.context)
+        return value
+
     def _getETagCores(self, unmarshalled_field_values=None):
         """Calculate the ETag for an entry.
 
@@ -1444,6 +1464,16 @@ class EntryResource(CustomOperationResourceMixin,
             return error
         return self.applyChanges(changeset)
 
+    def _applyChangesPostHook(self):
+        """See `EntryManipulatingResource`."""
+        # Also remove the modified object from the representation
+        # cache. This ensures a 209 status code will be accompanied
+        # with a brand new representation.
+        cache = self._representation_cache
+        if cache is not None:
+            cache.delete(self.context)
+
+
     @property
     def type_url(self):
         "The URL to the resource type for this resource."
@@ -1548,11 +1578,19 @@ class EntryResource(CustomOperationResourceMixin,
             else:
                 # We have a representation, but we might not be able
                 # to use it as-is.
+
+                # First, check to see if the user can see this
+                # representation at all. If absoluteURL raises
+                # Unauthorized, they can't see it--they shouldn't even
+                # know its URL.
+                absoluteURL(self.context, self.request)
+
                 if len(redacted_fields) != 0:
-                    # We can't use the representation as is. We need
-                    # to deserialize it, redact certain fields, and
-                    # reserialize it. Hopefully this is faster than
-                    # generating the representation from scratch!
+                    # The user can see parts of this representation
+                    # but not other parts. We need to deserialize it,
+                    # redact certain fields, and reserialize
+                    # it. Hopefully this is faster than generating the
+                    # representation from scratch!
                     json = simplejson.loads(representation)
                     for field in redacted_fields:
                         json[field] = self.REDACTED_VALUE
