@@ -151,10 +151,17 @@ def export_as_webservice_entry(singular_name=None, plural_name=None):
             if tag_stack['type'] != FIELD_TYPE:
                 continue
             for version, tags in tag_stack.stack:
-                # Set 'as' for every version in which the field is published
-                # but no 'as' is specified.
-                if tags.get('as') is None and tags.get('exported') != False:
-                    tags['as'] = name
+                # Set 'as' for every version in which the field is
+                # published but no 'as' is specified. Also set
+                # 'original_name' for every version in which the field
+                # is published--this will help with performance
+                # optimizations around permission checks.
+                if tags.get('exported') != False:
+                    tags['original_name'] = name
+                    if tags.get('as') is None:
+                        tags['as'] = name
+
+
 
         annotate_exported_methods(interface)
         return interface
