@@ -409,6 +409,13 @@ class IWebServiceConfiguration(Interface):
         service root for the latest version (which probably changes more
         often).""")
 
+    enable_server_side_representation_cache = Bool(
+        title=u"Enable the server-side representation cache.",
+        default=True,
+        description=u"""If this is false, the server-side representation
+        cache will not be used, even if one is registered."""
+        )
+
     service_description = TextLine(
         title=u"Service description",
         description=u"""A human-readable description of the web service.
