@@ -36,6 +36,7 @@ from lazr.restful.interfaces import (
     IByteStorage, ICollection, ICollectionField, IEntry, IEntryField,
     IHTTPResource, IServiceRootResource, IWebBrowserInitiatedRequest,
     IWebServiceClientRequest, IWebServiceConfiguration, IWebServiceVersion)
+from lazr.restful.utils import tag_request_with_version_name
 
 
 class WebServicePublicationMixin:
@@ -253,13 +254,7 @@ class WebServiceRequestTraversal(object):
                     break
         if version is None:
             raise NotFound(self, '', self)
-        self.annotations[self.VERSION_ANNOTATION] = version
-
-        # Find the version-specific interface this request should
-        # provide, and provide it.
-        to_provide = getUtility(IWebServiceVersion, name=version)
-        alsoProvides(self, to_provide)
-        self.version = version
+        tag_request_with_version_name(self, version)
 
         # Find the appropriate service root for this version and set
         # the publication's application appropriately.
@@ -309,7 +304,6 @@ def browser_request_to_web_service_request(
     web_service_request = config.createRequest(body, environ)
     web_service_request.setVirtualHostRoot(
         names=[config.path_override, web_service_version])
-    web_service_request.annotations[web_service_request.VERSION_ANNOTATION] = (
-        web_service_request)
+    tag_request_with_version_name(web_service_request, web_service_version)
     web_service_request._vh_root = website_request.getVirtualHostRoot()
     return web_service_request
