@@ -373,14 +373,20 @@ class BaseRepresentationCache(object):
     """
     implements(IRepresentationCache)
 
+    DO_NOT_CACHE = object()
+
     def get(self, obj, media_type, version, default=None):
         """See `IRepresentationCache`."""
         key = self.key_for(obj, media_type, version)
+        if key is self.DO_NOT_CACHE:
+            return default
         return self.get_by_key(key, default)
 
     def set(self, obj, media_type, version, representation):
         """See `IRepresentationCache`."""
         key = self.key_for(obj, media_type, version)
+        if key is self.DO_NOT_CACHE:
+            return
         return self.set_by_key(key, representation)
 
     def delete(self, object):
@@ -388,7 +394,8 @@ class BaseRepresentationCache(object):
         config = getUtility(IWebServiceConfiguration)
         for version in config.active_versions:
             key = self.key_for(object, HTTPResource.JSON_TYPE, version)
-            self.delete_by_key(key)
+            if key is not self.DO_NOT_CACHE:
+                self.delete_by_key(key)
 
     def key_for(self, object, media_type, version):
         """Generate a unique key for an object/media type/version.
@@ -466,7 +473,7 @@ class DictionaryBasedRepresentationCache(BaseRepresentationCache):
 
     def delete_by_key(self, key):
         """Implementation of a `BaseRepresentationCache` method."""
-        del self.dict[key]
+        self.dict.pop(key, None)
 
 
 BaseWebServiceConfiguration = implement_from_dict(
