@@ -32,9 +32,9 @@ from lazr.restful.interfaces import (
     ICollection, ICollectionField, IEntry, IJSONRequestCache,
     IReferenceChoice, IResourceDELETEOperation, IResourceGETOperation,
     IResourceOperation, IResourcePOSTOperation, IScopedCollection,
-    ITopLevelEntryLink, IWebServiceClientRequest, IWebServiceVersion,
-    LAZR_WEBSERVICE_NAME)
-from lazr.restful.utils import get_current_browser_request
+    ITopLevelEntryLink, IWebServiceClientRequest, IWebServiceConfiguration,
+    IWebServiceVersion, LAZR_WEBSERVICE_NAME)
+from lazr.restful.utils import get_current_web_service_request
 
 
 class WadlDocstringLinker(DocstringLinker):
@@ -110,13 +110,13 @@ class WebLayerAPI:
     @property
     def is_entry(self):
         """Whether the object is published as an entry."""
-        return queryMultiAdapter(
-            (self.context, get_current_browser_request()), IEntry) != None
+        request = get_current_web_service_request()
+        return queryMultiAdapter((self.context, request), IEntry) != None
 
     @property
     def json(self):
         """Return a JSON description of the object."""
-        request = IWebServiceClientRequest(get_current_browser_request())
+        request = get_current_web_service_request
         if queryMultiAdapter((self.context, request), IEntry):
             resource = EntryResource(self.context, request)
         else:
@@ -137,7 +137,7 @@ class WadlResourceAPI(RESTUtilityBase):
     @property
     def url(self):
         """Return the full URL to the resource."""
-        return absoluteURL(self.context, get_current_browser_request())
+        return absoluteURL(self.context, get_current_web_service_request())
 
 
 class WadlEntryResourceAPI(WadlResourceAPI):
@@ -182,7 +182,7 @@ class WadlCollectionResourceAPI(WadlResourceAPI):
             else:
                 relationship_name = self.context.relationship.__name__
             return (absoluteURL(self.context.context,
-                                get_current_browser_request()) + '/' +
+                                get_current_web_service_request()) + '/' +
                     urllib.quote(relationship_name))
         else:
             return super(WadlCollectionResourceAPI, self).url
@@ -220,6 +220,19 @@ class WadlServiceRootResourceAPI(RESTUtilityBase):
         """Return the full URL to the resource."""
         return self._service_root_url()
 
+    @property
+    def description(self):
+        return getUtility(IWebServiceConfiguration).service_description
+
+    @property
+    def service_version(self):
+        return self.resource.request.version
+
+    @property
+    def version_description(self):
+        config = getUtility(IWebServiceConfiguration)
+        return config.version_descriptions.get(self.service_version, None)
+
     @property
     def top_level_resources(self):
         """Return a list of dicts describing the top-level resources."""
@@ -287,7 +300,7 @@ class WadlResourceAdapterAPI(RESTUtilityBase):
         model_class = self._model_class
         operations = []
         request_interface = getUtility(
-            IWebServiceVersion, get_current_browser_request().version)
+            IWebServiceVersion, get_current_web_service_request().version)
         for interface in (IResourceGETOperation, IResourcePOSTOperation):
             operations.extend(getGlobalSiteManager().adapters.lookupAll(
                     (model_class, request_interface), interface))
@@ -309,7 +322,7 @@ class WadlEntryInterfaceAdapterAPI(WadlResourceAdapterAPI):
         super(WadlEntryInterfaceAdapterAPI, self).__init__(
             entry_interface, IEntry)
         self.utility = EntryAdapterUtility.forEntryInterface(
-            entry_interface, get_current_browser_request())
+            entry_interface, get_current_web_service_request())
 
     @property
     def entry_page_representation_link(self):
@@ -383,7 +396,7 @@ class WadlEntryAdapterAPI(WadlResourceAdapterAPI):
     def supports_delete(self):
         """Return true if this entry responds to DELETE."""
         request_interface = getUtility(
-            IWebServiceVersion, get_current_browser_request().version)
+            IWebServiceVersion, get_current_web_service_request().version)
         operations = getGlobalSiteManager().adapters.lookupAll(
             (self._model_class, request_interface),
             IResourceDELETEOperation)
@@ -521,7 +534,7 @@ class WadlFieldAPI(RESTUtilityBase):
         assert schema is not IObject, (
             "Null schema provided for %s" % self.field.__name__)
         return EntryAdapterUtility.forSchemaInterface(
-            schema, get_current_browser_request())
+            schema, get_current_web_service_request())
 
 
     @property
@@ -546,7 +559,7 @@ class WadlTopLevelEntryLinkAPI(RESTUtilityBase):
     def type_link(self):
         return EntryAdapterUtility.forSchemaInterface(
             self.entry_link.entry_type,
-            get_current_browser_request()).type_link
+            get_current_web_service_request()).type_link
 
 
 class WadlOperationAPI(RESTUtilityBase):
