@@ -6,12 +6,14 @@ __metaclass__ = type
 __all__ = [
     'camelcase_to_underscore_separated',
     'get_current_browser_request',
+    'get_current_web_service_request',
     'implement_from_dict',
     'make_identifier_safe',
     'safe_js_escape',
     'safe_hasattr',
     'smartquote',
     'simple_popen2',
+    'tag_request_with_version_name',
     'VersionedDict',
     ]
 
@@ -24,8 +26,12 @@ import subprocess
 
 from simplejson import encoder
 
+from zope.component import getUtility
 from zope.schema import getFieldsInOrder
-from zope.interface import classImplements
+from zope.interface import alsoProvides, classImplements
+
+from lazr.restful.interfaces import (
+    IWebServiceClientRequest, IWebServiceVersion)
 
 
 missing = object()
@@ -217,6 +223,33 @@ def get_current_browser_request():
     return requests[0]
 
 
+def get_current_web_service_request():
+    """Return the current web service request.
+
+    This may be a new request object based on the browser request (if
+    the client is a web browser that might make AJAX calls to a
+    separate web service) or it may be the same as the browser request
+    (if the client is a web service client accessing the service
+    directly).
+
+    :return: An object providing IWebserviceClientRequest.
+    """
+    request = get_current_browser_request()
+    if request is None:
+        return None
+    return IWebServiceClientRequest(request)
+
+
+def tag_request_with_version_name(request, version):
+    """Tag a request with a version name and marker interface."""
+    request.annotations[request.VERSION_ANNOTATION] = version
+    # Find the version-specific marker interface this request should
+    # provide, and provide it.
+    to_provide = getUtility(IWebServiceVersion, name=version)
+    alsoProvides(request, to_provide)
+    request.version = version
+
+
 def simple_popen2(command, input, env=None, in_bufsize=1024, out_bufsize=128):
     """Run a command, give it input on its standard input, and capture its
     standard output.
